<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 *
 * @package    VideoZ
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower( $themename ) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );

}

/**
 * Defines an array of options that will be used to generate the settings page 
 * and be saved in the database.
 *
 * @since  1.0.0
 * @access public
 */
function optionsframework_options() {

	// Pull all tags into an array.
	$tags = array();
	$tags_obj = get_tags();
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_html( $tag->name );
	}

	// Pull all the categories into an array
	$categories = array();
	$categories_obj = get_categories();
	foreach ( $categories_obj as $category ) {
		$categories[$category->cat_ID] = esc_html( $category->cat_name );
	}

	// Background thumbnail path.
	$imgpath =  get_template_directory_uri() . '/assets/img/bg/';

	$options = array();

	$options[] = array(
		'name' => __( 'General', 'videoz' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Logo Uploader', 'videoz' ),
		'desc' => __( 'Upload your custom logo, it will automatically replace the Site Title', 'videoz' ),
		'id'   => 'videoz_logo',
		'type' => 'upload'
	);

	$options[] = array(
		'name' => __( 'Favicon Uploader', 'videoz' ),
		'desc' => __( 'Upload your custom favicon.', 'videoz' ),
		'id'   => 'videoz_favicon',
		'type' => 'upload'
	);

	$options[] = array(
		'name'  => __( 'FeedBurner URL', 'videoz' ),
		'desc'  => __( 'Enter your full FeedBurner URL. If you wish to use FeedBurner over the standard WordPress feed.', 'videoz' ),
		'id'    => 'videoz_feedburner_url',
		'placeholder' => 'http://feeds.feedburner.com/ThemeJunkie',
		'type'  => 'text'
	);

	$options[] = array(
		'name'    => __( 'Colors', 'videoz' ),
		'desc'    => __( 'Pick a skin/color you like.', 'videoz' ),
		'id'      => 'videoz_colors',
		'type'    => 'select',
		'std'     => 'default',
		'options' => array(
			'default' => __( 'Default', 'videoz' ),
			'dark'    => __( 'Dark', 'videoz' ),
			'light'   => __( 'Light', 'videoz' )
		)
	);

	$options[] = array(
		'name' => __( 'Single Post', 'videoz' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Display author info ', 'videoz' ),
		'desc' => __( 'Enable the author biographical info.', 'videoz' ),
		'id'   => 'videoz_post_author',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Display share links', 'videoz' ),
		'desc' => __( 'Enable the share links.', 'videoz' ),
		'id'   => 'videoz_post_share',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Before Content Advertisement', 'videoz' ),
		'desc' => __( 'Your ad will appear on single post before content.', 'videoz' ),
		'id'   => 'videoz_ad_single_before',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'After Content Advertisement', 'videoz' ),
		'desc' => __( 'Your ad will appear on single post after content.', 'videoz' ),
		'id'   => 'videoz_ad_single_after',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'Social Links', 'videoz' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Enable ', 'videoz' ),
		'desc' => __( 'Enable social links', 'videoz' ),
		'id'   => 'videoz_enable_social',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Facebook', 'videoz' ),
		'desc' => __( 'Facebook profile url', 'videoz' ),
		'id'   => 'videoz_fb',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Twitter', 'videoz' ),
		'desc' => __( 'Twitter profile url', 'videoz' ),
		'id'   => 'videoz_tw',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Google Plus', 'videoz' ),
		'desc' => __( 'Google Plus profile url', 'videoz' ),
		'id'   => 'videoz_gplus',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Pinterest', 'videoz' ),
		'desc' => __( 'Pinterest profile url', 'videoz' ),
		'id'   => 'videoz_pinterest',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Custom Code', 'videoz' ),
		'type' => 'heading'
	);

	$options['videoz_script_head'] = array(
		'name' => __( 'Header code', 'videoz' ),
		'desc' => __( 'If you need to add custom scripts to your header (meta tag verification, google fonts url), you should enter them in the box. They will be added before &lt;/head&gt; tag', 'videoz' ),
		'id'   => 'videoz_script_head',
		'type' => 'textarea'
	);

	$options['videoz_script_footer'] = array(
		'name' => __( 'Footer code', 'videoz' ),
		'desc' => __( 'If you need to add custom scripts to your footer (like google analytic script), you should enter them in the box. They will be added before &lt;/body&gt; tag', 'videoz' ),
		'id'   => 'videoz_script_footer',
		'type' => 'textarea'
	);

	/* Return the theme settings data. */
	return $options;
}