<?php
/**
 * Recent Posts with Thumbnail based on category widget for home page.
 *
 * @package    VideoZ
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class VideoZ_Home_Recent_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-videoz-home-recent',
			'description' => __( 'Display recent posts with thumbnails based on category. Please use it only in Home sidebar!', 'videoz' )
		);

		// Create the widget.
		$this->WP_Widget(
			'videoz-home-recent',                                          // $this->id_base
			__( '&raquo; Home - Recent Posts Thumbnails', 'videoz' ), // $this->name
			$widget_options                                           // $this->widget_options
		);

	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// If user have not selected any category then display none.
		if ( empty( $instance['cat'] ) ) {
			return;
		}

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Pull the selected category.
			$cat_id = $instance['cat'];

			// Get the category.
			$category = get_category( $cat_id );

			// Get the category archive link.
			$cat_link = get_category_link( $cat_id );

			// Posts query arguments.
			$args = array(
				'post_type'      => 'post',
				'posts_per_page' => 3
			);

			// Limit to category based on user selected tag.
			if ( ! empty( $instance['cat'] ) ) {
				$args['cat'] = $instance['cat'];
			}

			// Allow dev to filter the post arguments.
			$query = apply_filters( 'videoz_home_recent_args', $args );

			// The post query.
			$posts = new WP_Query( $query );

			if ( $posts->have_posts() ) : ?>

				<div class="recent-content clearfix <?php echo sanitize_html_class( $instance['color'] ); ?>">
					
					<h3 class="section-title">
						<?php echo $category->name; ?><span class="see-all"><a href="<?php echo esc_url( $cat_link ); ?>"><?php _e( 'View More', 'truenews' ); ?> <i class="fa fa-angle-right"></i></a></span>
					</h3>

					<?php $i = 0; ?>

					<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

						<?php
						$class = '';
						if ( ++$i % 3 === 0 ) {
							$class = 'last-post';
						}
						?>

						<article id="post-<?php the_ID(); ?>" <?php post_class( $class ); ?> <?php hybrid_attr( 'post' ); ?>>

							<?php $video = hybrid_media_grabber( array( 'type' => 'video', 'split_media' => true, 'width' => 960 ) ); ?>
							
							<?php if ( $video ) : ?>
							<a class="venobox" data-type="inline" href="#entry-video-<?php the_ID(); ?>">
							<?php endif; ?>
								<?php if ( has_post_thumbnail() ) : ?>
									<?php the_post_thumbnail( 'videoz-thumb', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<?php endif; ?>
								<?php if ( $video ) : ?>
									<div class="overlay">
										<span class="play-button"><i class="fa fa-play"></i></span>
									</div>
								<?php endif; ?>
							<?php if ( $video ) : ?>
							</a>
							<?php endif; ?>
							
							<?php if ( $video ) : ?>
								<div id="entry-video-<?php the_ID(); ?>" style="display: none;"><?php echo $video; ?></div>
							<?php endif; ?>

							<div class="hentry-bottom clearfix">

								<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

								<div class="byline">
									<time class="entry-date updated" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ); ?>><span><?php echo esc_html( get_the_date() ); ?></span></time>
									<span class="entry-separator">|</span>
									<span class="entry-view"><?php echo do_shortcode( '[entry-views after="' . __( ' Views', 'videoz' ) . '"]' ); ?></span>
								</div>

								<?php if(function_exists('the_ratings')) { the_ratings(); } ?>

							</div>
							
						</article><!-- #post-## -->

					<?php endwhile; ?>

				</div>
			
			<?php endif;

			// Reset the query.
			wp_reset_postdata();
		
		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance          = $new_instance;
		$instance['color'] = $new_instance['color'];
		$instance['cat']   = $new_instance['cat'];

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'color' => '',
			'cat'   => '',
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'color' ); ?>">
				<?php _e( 'Color', 'videoz' ); ?>
			</label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'color' ); ?>" name="<?php echo $this->get_field_name( 'color' ); ?>" style="width:100%;">
				<option value=""><?php _e( 'White', 'videoz' ) ?></option>
				<option value="recent-orange" <?php selected( $instance['color'], 'recent-orange' ); ?>><?php _e( 'Orange', 'videoz' ) ?></option>
				<option value="recent-green" <?php selected( $instance['color'], 'recent-green' ); ?>><?php _e( 'Green', 'videoz' ) ?></option>
				<option value="recent-purple" <?php selected( $instance['color'], 'recent-purple' ); ?>><?php _e( 'Purple', 'videoz' ) ?></option>
				<option value="recent-blue" <?php selected( $instance['color'], 'recent-blue' ); ?>><?php _e( 'Blue', 'videoz' ) ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php _e( 'Choose Category:', 'videoz' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat' ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<?php foreach( $categories as $category ) { ?>
					<option value="<?php echo esc_attr( $category->term_id ); ?>" <?php selected( $instance['cat'], $category->term_id ); ?>><?php echo esc_html( $category->name ); ?></option>
				<?php } ?>
			</select>
		</p>

	<?php

	}

}