<?php
/**
 * Tabbed widget.
 *
 * @package    VideoZ
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class VideoZ_Tabs_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-videoz-tabs tabs-widget posts-thumbnail-widget',
			'description' => __( 'Display popular posts, recent posts, recent comments and tags in tabs.', 'videoz' )
		);

		// Create the widget.
		$this->WP_Widget(
			'videoz-tabs',                  // $this->id_base
			__( '&raquo; Tabs', 'videoz' ), // $this->name
			$widget_options                 // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;
		?>
		
		<ul class="tabs-nav">
			<li class="active"><a href="#tab1"><?php echo esc_attr( $instance['popular'] ); ?></a></li>
			<li><a href="#tab2"><?php echo esc_attr( $instance['posts'] ); ?></a></a></li>
			<li><a href="#tab3"><?php echo esc_attr( $instance['comments'] ); ?></a></a></li>
			<li><a href="#tab4"><?php echo esc_attr( $instance['tags'] ); ?></a></li>
		</ul>

		<div class="tabs-container">
			<div class="tab-content" id="tab1">
				<?php echo videoz_popular_posts(); ?>
			</div>

			<div class="tab-content" id="tab2">
				<?php echo videoz_latest_posts(); ?>
			</div>

			<div class="tab-content" id="tab3">
				<?php the_widget( 'WP_Widget_Recent_Comments' ); ?>				
			</div>

			<div class="tab-content" id="tab4">
				<?php the_widget( 'WP_Widget_Tag_Cloud' ); ?>				
			</div>
		</div>

		<?php
		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['popular']  = strip_tags( $new_instance['popular'] );
		$instance['posts']    = strip_tags( $new_instance['posts'] );
		$instance['comments'] = strip_tags( $new_instance['comments'] );
		$instance['tags']     = strip_tags( $new_instance['tags'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'popular'  => esc_html__( 'Popular', 'videoz' ),
			'posts'    => esc_html__( 'Latest', 'videoz' ),
			'comments' => esc_html__( 'Comments', 'videoz' ),
			'tags'     => esc_html__( 'Tags', 'videoz' )
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'popular' ); ?>">
				<?php _e( 'Popular posts title:', 'videoz' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'popular' ); ?>" name="<?php echo $this->get_field_name( 'popular' ); ?>" value="<?php echo esc_attr( $instance['popular'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'posts' ); ?>">
				<?php _e( 'Recent posts title:', 'videoz' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'posts' ); ?>" name="<?php echo $this->get_field_name( 'posts' ); ?>" value="<?php echo esc_attr( $instance['posts'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'comments' ); ?>">
				<?php _e( 'Recent comments title:', 'videoz' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'comments' ); ?>" name="<?php echo $this->get_field_name( 'comments' ); ?>" value="<?php echo esc_attr( $instance['comments'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'tags' ); ?>">
				<?php _e( 'Tags title:', 'videoz' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'tags' ); ?>" name="<?php echo $this->get_field_name( 'tags' ); ?>" value="<?php echo esc_attr( $instance['tags'] ); ?>" />
		</p>

	<?php

	}

}

/**
 * Popular Posts by comment
 *
 * @since 1.0.0
 */
function videoz_popular_posts() {

	// Posts query arguments.
	$args = array(
		'posts_per_page' => 5,
		'orderby'        => 'comment_count',
		'post_type'      => 'post'
	);

	// The post query
	$popular = get_posts( $args );

	global $post;

	if ( $popular ) {
		$html = '<ul>';

			foreach ( $popular as $post ) :
				setup_postdata( $post );

				$html .= '<li class="clearfix">';
					$html .= '<a class="entry-thumbnail" href="' . esc_url( get_permalink( $post->ID ) ) . '" rel="bookmark">' . get_the_post_thumbnail( $post->ID, 'videoz-widget', array( 'class' => 'entry-thumb', 'alt' => esc_attr( get_the_title( $post->ID ) ) ) ) . '<span class="play-button"><i class="fa fa-play"></i></span></a>';
					$html .= '<h2 class="entry-title"><a href="' . esc_url( get_permalink( $post->ID ) ) . '" rel="bookmark">' . esc_attr( get_the_title( $post->ID ) ) . '</a></h2>';
					$html .= '<div class="entry-meta">' . sprintf( __( '%s ago', 'videoz' ), human_time_diff( get_the_date( 'U' ), current_time( 'timestamp' ) ) ) . '</div>';
				$html .= '</li>';

			endforeach;

		$html .= '</ul>';
	}

	// Reset the query.
	wp_reset_postdata();

	if ( isset( $html ) ) {
		return $html;
	}

}

/**
 * Recent Posts
 *
 * @since 1.0.0
 */
function videoz_latest_posts() {

	// Posts query arguments.
	$args = array(
		'post_type'      => 'post',
		'posts_per_page' => 5
	);

	// The post query
	$recent = get_posts( $args );

	global $post;

	if ( $recent ) {
		$html = '<ul>';

			foreach ( $recent as $post ) :
				setup_postdata( $post );

				$html .= '<li class="clearfix">';
					$html .= '<a class="entry-thumbnail" href="' . esc_url( get_permalink( $post->ID ) ) . '" rel="bookmark">' . get_the_post_thumbnail( $post->ID, 'videoz-widget', array( 'class' => 'entry-thumb', 'alt' => esc_attr( get_the_title( $post->ID ) ) ) ) . '<span class="play-button"><i class="fa fa-play"></i></span></a>';
					$html .= '<h2 class="entry-title"><a href="' . esc_url( get_permalink( $post->ID ) ) . '" rel="bookmark">' . esc_attr( get_the_title( $post->ID ) ) . '</a></h2>';
					$html .= '<div class="entry-meta">' . sprintf( __( '%s ago', 'videoz' ), human_time_diff( get_the_date( 'U' ), current_time( 'timestamp' ) ) ) . '</div>';
				$html .= '</li>';

			endforeach;

		$html .= '</ul>';
	}

	// Reset the query.
	wp_reset_postdata();

	if ( isset( $html ) ) {
		return $html;
	}

}